# python_library
python_library

 
1. pip install  twine
2. python setup.py sdist　
3. twine upload dist/*
这里执行之后需要pypi的账号密码


测试
4. pip install  demo_wmy_meta


setup程序参数

name：需要唯一  以后pip的时候的name

version  版本，  pipy上会记录历史版本

url  gitlab/github的项目链接


